==> wawa-service-api-0.0.32-20180511.062553-22-sources.jar: cn/com/wawa/service/api/dto/user/UserDto.java <==
package cn.com.wawa.service.api.dto.user;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by danke on 2017/12/11.
 * 用户基本信息dto
 */
public class UserDto implements Serializable {

    private Long id;

    private String nickName;

    private String wxAvatar;

    private String localAvatar;

    private String openId;

    private String unionId;

    private Integer sex;

    private String province;

    private String city;

    private String country;

    private String inviteCode;//邀请码

    private String channelId;

    private Long coin;

    private Long bonusCoin;

    private Long freeCoin;

    private Long switches;

    private Date gmtCreate;

    private Date gmtModified;

    private String userType;

    private UserCoinDto userCoinDto;

    private boolean isBlack;

    private Long    wawaDepositNum;//娃娃数量

    private Integer    wawaAllNum;//娃娃数量

    private UserAddressDto userAddressDto;

    private Integer userChannel;

    private String totalCatchRate;
    private String strongCatchRate;
    private String weakCatchRate;

    /**
     * 经典玩法消耗
     */
    private Integer classicGameCost;
    /**
     * 限时玩法消耗币
     */
    private Integer timeLimitGameCost;

    /**
     * 兑换券余额
     */
    private Integer balance;
    /**
     * 兑换券历史总和
     */
    private Integer countHistory;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getWxAvatar() {
        return wxAvatar;
    }

    public void setWxAvatar(String wxAvatar) {
        this.wxAvatar = wxAvatar;
    }

    public String getLocalAvatar() {
        return localAvatar;
    }

    public void setLocalAvatar(String localAvatar) {
        this.localAvatar = localAvatar;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getInviteCode() {
        return inviteCode;
    }

    public void setInviteCode(String inviteCode) {
        this.inviteCode = inviteCode;
    }

    public String getChannelId() {
        return channelId;
    }

    public void setChannelId(String channelId) {
        this.channelId = channelId;
    }

    public Long getCoin() {
        return coin;
    }

    public void setCoin(Long coin) {
        this.coin = coin;
    }

    public Long getBonusCoin() {
        return bonusCoin;
    }

    public void setBonusCoin(Long bonusCoin) {
        this.bonusCoin = bonusCoin;
    }

    public Long getFreeCoin() {
        return freeCoin;
    }

    public void setFreeCoin(Long freeCoin) {
        this.freeCoin = freeCoin;
    }

    public Long getSwitches() {
        return switches;
    }

    public void setSwitches(Long switches) {
        this.switches = switches;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public UserCoinDto getUserCoinDto() {
        return userCoinDto;
    }

    public void setUserCoinDto(UserCoinDto userCoinDto) {
        this.userCoinDto = userCoinDto;
    }

    public UserAddressDto getUserAddressDto() {
        return userAddressDto;
    }

    public void setUserAddressDto(UserAddressDto userAddressDto) {
        this.userAddressDto = userAddressDto;
    }

    public Integer getWawaAllNum() {
        return wawaAllNum;
    }

    public void setWawaAllNum(Integer wawaAllNum) {
        this.wawaAllNum = wawaAllNum;
    }

    public Long getWawaDepositNum() {
        return wawaDepositNum;
    }

    public void setWawaDepositNum(Long wawaDepositNum) {
        this.wawaDepositNum = wawaDepositNum;
    }

    public String getUserType() {
        return userType;
    }

    public void setUserType(String userType) {
        this.userType = userType;
    }

    public boolean isBlack() {
        return isBlack;
    }

    public void setBlack(boolean black) {
        isBlack = black;
    }

    public Integer getUserChannel() {
        return userChannel;
    }

    public void setUserChannel(Integer userChannel) {
        this.userChannel = userChannel;
    }

    public String getTotalCatchRate() {
        return totalCatchRate;
    }

    public void setTotalCatchRate(String totalCatchRate) {
        this.totalCatchRate = totalCatchRate;
    }

    public String getStrongCatchRate() {
        return strongCatchRate;
    }

    public void setStrongCatchRate(String strongCatchRate) {
        this.strongCatchRate = strongCatchRate;
    }

    public String getWeakCatchRate() {
        return weakCatchRate;
    }

    public void setWeakCatchRate(String weakCatchRate) {
        this.weakCatchRate = weakCatchRate;
    }

    public Integer getClassicGameCost() {
        return classicGameCost;
    }

    public void setClassicGameCost(Integer classicGameCost) {
        this.classicGameCost = classicGameCost;
    }

    public Integer getTimeLimitGameCost() {
        return timeLimitGameCost;
    }

    public void setTimeLimitGameCost(Integer timeLimitGameCost) {
        this.timeLimitGameCost = timeLimitGameCost;
    }

    public Integer getBalance() {
        return balance;
    }

    public void setBalance(Integer balance) {
        this.balance = balance;
    }

    public Integer getCountHistory() {
        return countHistory;
    }

    public void setCountHistory(Integer countHistory) {
        this.countHistory = countHistory;
    }
}

==> wawa-service-api-0.0.33-20180518.071531-8-sources.jar: cn/com/wawa/service/api/dto/user/UserDto.java <==
package cn.com.wawa.service.api.dto.user;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by danke on 2017/12/11.
 * 用户基本信息dto
 */
@Data
public class UserDto implements Serializable {

    private Long id;

    private String nickName;

    private String wxAvatar;

    private String localAvatar;

    private String openId;

    private String unionId;

    private Integer sex;

    private String province;

    private String city;

    private String country;

    private String inviteCode;//邀请码

    private String channelId;

    private Long coin;

    private Long bonusCoin;

    private Long freeCoin;

    private Long switches;

    private Date gmtCreate;

    private Date gmtModified;

    private String userType;

    private UserCoinDto userCoinDto;

    private boolean isBlack;

    private Long wawaDepositNum;//娃娃数量

    private Integer wawaAllNum;//娃娃数量

    private UserAddressDto userAddressDto;

    private Integer userChannel;

    private String totalCatchRate;
    private String strongCatchRate;
    private String weakCatchRate;

    /**
     * 经典玩法消耗
     */
    private Integer classicGameCost;
    /**
     * 限时玩法消耗币
     */
    private Integer timeLimitGameCost;

    /**
     * 兑换券余额
     */
    private Integer balance;
    /**
     * 兑换券历史总和
     */
    private Integer countHistory;

    /**
     * 1v1胜率,为整数 如30
     */
    private String winRate;
    /**
     * 1v1匹配消耗
     */
    private Long countCostPrice;
    /**
     * 1v1平台抽成
     */
    private Long countFee;
    /**
     * 1v1赚取
     */
    private Long countWinCoin;
    /**
     * 1v1获胜场次
     */
    private Integer totalWin;
    /**
     * 1v1全部场次
     */
    private Integer totalNum;


}
